=======================
``sidekick.properties``
=======================

.. currentmodule:: sidekick.properties

Functions in this module are helpers intended to create convenient and
declarative idioms when declaring classes. Perhaps it is not entirely correct
calling them "functional", but since some patterns such as lazy properties
are common in functional libraries, Sidekick has a module for doing that.


Properties and descriptors
==========================

.. autosummary::
   lazy
   alias
   delegate_to
   property


API reference
=============

.. automodule:: sidekick.properties
   :members:
   :inherited-members:
